// Set Pivot to Selected Point.js
// (c) 2012 Nelson Santos
//
// This script is in the public domain. Feel free to modify it or use 
// it as a starting point for your own creations.
//
// Purpose:
//    This Cheetah3D script sets a polygon object's pivot point to the currently selected point.
//
// Installation:
//    Copy this script file to ~/Library/Application Support/Cheetah3D/scripts/Macro
//

function main(doc)
{
	// Get the selected object
	var currentObj = doc.selectedObject();

	// Make sure we have a valid object
	if (currentObj == null || currentObj.family() != NGONFAMILY)
	{
		OS.beep();
		OS.messageBox("Error", "Please select a single point on a polygon object before calling this script.");
		return;
	}

	// Get the polygon object data and number of vertices.
	var polycore = currentObj.core();
	var vertexCount = polycore.vertexCount();
	
	// Loop through all the vertices to find a selected vertex.
	var selectedVertex = null;
	var multipleVerticesSelected = false;
	for (var i = 1; i <= vertexCount; i++)
	{
		if (polycore.vertexSelection(i))
		{
			// Check if a selected vertex was already found in a previous loop.  Do this to prevent this script from
			// running when there are multiple vertices selected.
			if (selectedVertex != null)
			{
				multipleVerticesSelected = true;
				break;
			}
			selectedVertex = polycore.vertex(i);
		}
	}
	
	// If no selected vertices found (or multiple vertices selected), inform user and exit.
	if (selectedVertex == null || multipleVerticesSelected)
	{
		OS.beep();
		OS.messageBox("Error", "Please select a single point on a polygon object before calling this script.");
		return;
	}

	// Update the current object's pivot parameter to the currently selected point.
	currentObj.setParameter("pivot", selectedVertex);
}
